Lucid DynamoDB:
===============

A simple python wrapper to AWS DynamoDB.

==== ==================== ================================ =======
S.No Functions            Description                      Status
==== ==================== ================================ =======
1    create_table         Create a new table if not exists Done
2    delete_table         Delete a table                   Done
3    read_all_table_names List out all the table names     Done
4    create_item          Create a new item                Done
5    delete_item          Delete items by filter           Done
6    read_item            Read an item                      Backlog
7    read_all_item        Read all item                    Backlog
8    read_items_by_filter Read items by filter             Backlog
9    update_item          Update an item by filter         Backlog
==== ==================== ================================ =======

Pypi package: https://pypi.org/project/LucidDynamodb/1.0.0/